@@ -35,6 +35,7 @@ import com.github.gwtbootstrap.client.ui.Modal;
 import com.github.gwtbootstrap.client.ui.TextArea;
 import com.github.gwtbootstrap.client.ui.TextBox;
 import com.github.gwtbootstrap.client.ui.constants.AlertType;
+import com.github.gwtbootstrap.client.ui.constants.ButtonType;
 import com.github.gwtbootstrap.client.ui.event.HiddenEvent;
 import com.github.gwtbootstrap.client.ui.event.HiddenHandler;
 import com.google.gwt.core.client.GWT;
@@ -203,11 +204,14 @@ public class ManageProductWidget extends Composite{
 
 		// async request to fetch the product
 		retrieveProductBean(productIdentifier);
-
 		listenEvents(this.eventBus);
 	}
 
 
+	/**
+	 * Liste events
+	 * @param eventBus
+	 */
 	private void listenEvents(HandlerManager eventBus) {
 		eventBus.addHandler(EnableConfirmButtonEvent.TYPE, new  EnableConfirmButtonEventHandler() {
 
@@ -281,9 +285,7 @@ public class ManageProductWidget extends Composite{
 
 									@Override
 									public void onClick(ClickEvent event) {
-
 										eventBus.fireEvent(new EnableConfirmButtonEvent());
-
 									}
 								});
 
@@ -319,7 +321,7 @@ public class ManageProductWidget extends Composite{
 								listBoxStatus.addItem("Select a new status");
 								listBoxStatus.getElement().<SelectElement>cast().getOptions().getItem(0).setDisabled(true);
 								for (Status availableStatus : statusToShow) {
-									listBoxStatus.addItem(availableStatus.toString());
+									listBoxStatus.addItem(availableStatus.toString(), availableStatus.toString());
 								}
 								listBoxStatus.setSelectedIndex(0);
 
@@ -327,9 +329,7 @@ public class ManageProductWidget extends Composite{
 
 									@Override
 									public void onChange(ChangeEvent event) {
-
 										eventBus.fireEvent(new EnableConfirmButtonEvent());
-
 									}
 								});
 
@@ -337,9 +337,7 @@ public class ManageProductWidget extends Composite{
 
 									@Override
 									public void onChange(ChangeEvent event) {
-
 										eventBus.fireEvent(new EnableConfirmButtonEvent());
-
 									}
 								});
 
@@ -388,17 +386,6 @@ public class ManageProductWidget extends Composite{
 		String report = "";
 		Set<String> hashtags = new HashSet<>();
 
-		// if the status has not be changed ...
-		if(listBoxStatus.getSelectedIndex() <= 0){
-			bean.setNewStatus(bean.getCurrentStatus());
-			report = "- The Status is unchanged";
-		}
-		else{
-			bean.setNewStatus(Status.fromString(listBoxStatus.getSelectedItemText()));
-			report = "- The Status has been changed to " + bean.getNewStatus().getOrigName();
-			hashtags.add(bean.getNewStatus().getOrigName());
-		}
-
 		manageProductModal.setCloseVisible(false);
 		cancelButton.setEnabled(false);
 		confirmButton.setEnabled(false);
@@ -425,7 +412,8 @@ public class ManageProductWidget extends Composite{
 				else if(cb.isConnect()){
 					addConnectionHashtag = true;
 					report += "\n\t - add connection with record " + cb.getKnowledgeBaseId() + ";";
-				}
+				}else
+					report += "\n\t - keep this suggestion " + cb.getKnowledgeBaseId() + ";";
 			}
 			
 			if(addConnectionHashtag)
@@ -445,37 +433,52 @@ public class ManageProductWidget extends Composite{
 		if(!bean.getSimilarGrsfRecords().isEmpty()){
 			report += "\n- Suggested merges:";
 			for(SimilarGRSFRecord sR: bean.getSimilarGrsfRecords()){
-
 				if(sR.isSuggestedMerge()){
 					bean.setMergesInvolved(true);
 					report += "\n\t - merge the current record with record " + sR.getKnowledgeBaseId() + ";";
 				}
-
-				if(bean.isMergesInvolved()){
-					report += "\n- The update involves a merge operation.";
-					hashtags.add(HashTagsOnUpdate.MERGE.getString());
-				}
+			}
+			if(bean.isMergesInvolved()){
+				report += "\n- The update involves a merge operation;";
+				hashtags.add(HashTagsOnUpdate.MERGE.getString());
 			}
 		}
+		
 		// set new values
 		bean.setAnnotation(new HTML(annotationArea.getText().trim()).getText());
 
 		if(bean.getAnnotation() != null && !bean.getAnnotation().isEmpty())
-			report += "\n- Annotation message is: " + bean.getAnnotation();
+			report += "\n- Annotation message is: " + bean.getAnnotation() + ";";
 
 		// traceability flag
 		Boolean traceabilityNewValue = traceabilityFlag.getValue();
 		boolean currentTraceabilitFlag = bean.isTraceabilityFlag();
 		if(!traceabilityNewValue.equals(currentTraceabilitFlag)){
-			report += "\n- Traceability flag has been changed to: " + traceabilityNewValue;
-
+			report += "\n- Traceability flag has been changed to: '" + traceabilityNewValue + "';";
 			if(traceabilityNewValue)
 				hashtags.add(HashTagsOnUpdate.TRACEABILITY_FLAG_SET.getString());
 			else
 				hashtags.add(HashTagsOnUpdate.TRACEABILITY_FLAG_UNSET.getString());
 		}
-
+		
+		// update the traceability flag
 		bean.setTraceabilityFlag(traceabilityNewValue);
+		
+		// force the new status in the listbox
+		if(bean.isMergesInvolved()){
+			bean.setNewStatus(Status.To_be_Merged);
+			report += "\n- The Status has been changed to '" + bean.getNewStatus().getOrigName() + "'.";
+		}
+		else if(listBoxStatus.getSelectedIndex() <= 0){
+			// if the status has not be changed ...
+			bean.setNewStatus(bean.getCurrentStatus());
+			report += "\n- The Status is unchanged.";
+		}
+		else{
+			bean.setNewStatus(Status.fromString(listBoxStatus.getSelectedItemText()));
+			report += "\n- The Status has been changed to '" + bean.getNewStatus().getOrigName() + "'.";
+			hashtags.add(bean.getNewStatus().getOrigName());
+		}
 
 		// set the report
 		bean.setReport(report);
@@ -495,6 +498,8 @@ public class ManageProductWidget extends Composite{
 				formUpdate.setVisible(false);
 				manageProductModal.setCloseVisible(true);
 				cancelButton.setEnabled(true);
+				cancelButton.setText("Ok");
+				cancelButton.setType(ButtonType.INFO);
 				loaderIcon.setVisible(false);
 				updateSucceeded = true;
 			}
