@@ -4,6 +4,7 @@ import static org.gcube.resources.discovery.icclient.ICFactory.client;
 import static org.gcube.resources.discovery.icclient.ICFactory.queryFor;
 
 import java.util.ArrayList;
+import java.util.Base64;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -12,6 +13,7 @@ import java.util.Set;
 import javax.servlet.http.HttpServletRequest;
 
 import org.gcube.common.authorization.library.provider.SecurityTokenProvider;
+import org.gcube.common.portal.GCubePortalConstants;
 import org.gcube.common.resources.gcore.GCoreEndpoint;
 import org.gcube.common.scope.api.ScopeProvider;
 import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogue;
@@ -57,6 +59,8 @@ public class SocialCommunications {
 	private static final String serviceName = "SocialNetworking";
 	private static final String serviceClass = "Portal";
 
+	public static final String USER_PROFILE_OID = "userIdentificationParameter";
+
 	// social operations
 	private static final String SOCIAL_SERVICE_APPLICATION_TOKEN = "2/tokens/generate-application-token";
 	private static final String SOCIAL_SERVICE_WRITE_APPLICATION_POST = "2/posts/write-post-app";
@@ -79,7 +83,7 @@ public class SocialCommunications {
 			+ "<br>your request for the record 'PRODUCT_TITLE' has been accepted."
 			+ "<br>You can inspect it here: LINK_RECORD.";
 
-	private static final String ADD_REPORT = "<br> This is a summary of the actions proposed: <br>REPORT_UPDATE<br>";
+	private static final String ADD_REPORT = "<br> <br>This is a summary of the actions proposed: <br>REPORT_UPDATE<br>";
 
 	// revert link 
 	private static final String REVERT_LINK_PIECE = "<br>The request involves a merge operation. You can reject the merge by exploiting this link LINK in the following 24 hours.";
@@ -89,7 +93,7 @@ public class SocialCommunications {
 			+ "<br>a revert operation (undo merge) has been requested on record RECORD_URL, by ADMIN_WHO_CHANGED.";
 
 	private static final String EMAIL_EDITOR_REVERT = "Dear ORIGINAL_USER,"
-			+"<br> a revert operation (undo merge) has been requested on this RECORD_URL you managed by ADMIN_WHO_CHANGED.";
+			+"<br>a revert operation (undo merge) has been requested on this RECORD_URL you managed by ADMIN_WHO_CHANGED.";
 
 	// post on revert
 	private static final String POST_ON_REVERT = "Dear members,"
@@ -150,8 +154,6 @@ public class SocialCommunications {
 		String currentScope = ScopeProvider.instance.get();
 		String tokenUser = SecurityTokenProvider.instance.get();
 
-		//return "b159b50c-c0f8-4a4c-bac9-b6149d6b81fc-98187548";
-
 		logger.info("Current scope for requireApplicationToken is " + currentScope + " and token is " + tokenUser.substring(0, 10) + "***************");
 		String basePath = serviceUrl;
 
@@ -169,7 +171,6 @@ public class SocialCommunications {
 				// ask token application
 				HttpPost postRequest = new HttpPost(basePath + SOCIAL_SERVICE_APPLICATION_TOKEN + "?gcube-token=" + tokenUser);
 				JSONObject requestToken = new JSONObject();
-				//				requestToken.put("app_id", APPLICATION_ID_CATALOGUE_MANAGER.split("\\.")[APPLICATION_ID_CATALOGUE_MANAGER.split("\\.").length - 1]); // TODO 
 				requestToken.put("app_id", APPLICATION_ID_CATALOGUE_MANAGER);
 				StringEntity input = new StringEntity(requestToken.toJSONString());
 				input.setContentType(MEDIATYPE_JSON);
@@ -213,7 +214,7 @@ public class SocialCommunications {
 	 * @throws Exception 
 	 */
 	@SuppressWarnings("unchecked")
-	public static void writePostOnRevert(String serviceUrl, RevertableOperationInfo rInfo, boolean enablePostNotification) throws Exception{
+	public static void writePostOnRevert(String serviceUrl, RevertableOperationInfo rInfo, boolean enablePostNotification, String userCurrentUrl) throws Exception{
 
 		// discover service endpoint for the social networking library
 		String currentScope = ScopeProvider.instance.get();
@@ -236,8 +237,20 @@ public class SocialCommunications {
 				// require url
 				String applicationToken = requireApplicationToken(serviceUrl);
 
+				final String profilePageURL = GCubePortalConstants.PREFIX_GROUP_URL + extractOrgFriendlyURL(userCurrentUrl) + GCubePortalConstants.USER_PROFILE_FRIENDLY_URL;
+
+				String userFullNameHighlightedCurrent = "<a class=\"link\" href=\"" + profilePageURL + "?"+
+						Base64.getEncoder().encodeToString(USER_PROFILE_OID.getBytes())+"="+
+						Base64.getEncoder().encodeToString(rInfo.getUserNameCurrentAdmin().getBytes())+"\">"+rInfo.getFullNameCurrentAdmin()+
+						"</a> ";
+
+				String userFullNameHighlightedOriginal = "<a class=\"link\" href=\"" + profilePageURL + "?"+
+						Base64.getEncoder().encodeToString(USER_PROFILE_OID.getBytes())+"="+
+						Base64.getEncoder().encodeToString(rInfo.getUserNameOriginalAdmin().getBytes())+"\">"+rInfo.getFullNameOriginalAdmin()+
+						"</a> ";
+
 				// replace
-				String message  = POST_ON_REVERT.replace("RECORD_URL", rInfo.getRecordUrl()).replace("ADMIN_WHO_CHANGED", rInfo.getFullNameCurrentAdmin()).replace("ORIGINAL_USER", rInfo.getFullNameOriginalAdmin());
+				String message  = POST_ON_REVERT.replace("RECORD_URL", rInfo.getRecordUrl()).replace("ADMIN_WHO_CHANGED", userFullNameHighlightedCurrent).replace("ORIGINAL_USER",userFullNameHighlightedOriginal);
 
 				// add hashtag
 				message +="<br><br>";
@@ -276,7 +289,7 @@ public class SocialCommunications {
 	 * @throws Exception 
 	 */
 	@SuppressWarnings("unchecked")
-	public static void writeProductPost(String serviceUrl, ManageProductBean bean, String username, String fullName, boolean enablePostNotification) throws Exception{
+	public static void writeProductPost(String serviceUrl, ManageProductBean bean, String username, String fullName, boolean enablePostNotification, String userCurrentUrl) throws Exception{
 
 		// discover service endpoint for the social networking library
 		String currentScope = ScopeProvider.instance.get();
@@ -299,9 +312,15 @@ public class SocialCommunications {
 				// require url
 				String applicationToken = requireApplicationToken(serviceUrl);
 
+				final String profilePageURL = GCubePortalConstants.PREFIX_GROUP_URL + extractOrgFriendlyURL(userCurrentUrl) + GCubePortalConstants.USER_PROFILE_FRIENDLY_URL;
+				String userFullNameHighlighted = "<a class=\"link\" href=\"" + profilePageURL + "?"+
+						Base64.getEncoder().encodeToString(USER_PROFILE_OID.getBytes())+"="+
+						Base64.getEncoder().encodeToString(username.getBytes())+"\">"+fullName+
+						"</a> ";
+
 				// replace
 				String message  = POST_MESSAGE.replace("PRODUCT_TITLE", bean.getTitle()).replace("LINK_RECORD", bean.getUrl()).
-						replace("USER_FULLNAME", fullName);
+						replace("USER_FULLNAME", userFullNameHighlighted);
 
 				if(bean.getReport() != null && !bean.getReport().isEmpty())
 					message += ADD_REPORT.replace("REPORT_UPDATE", bean.getReport());
@@ -336,6 +355,21 @@ public class SocialCommunications {
 		}
 	}
 
+	private static String extractOrgFriendlyURL(String portalURL) {
+		String groupRegEx = "/group/";
+		if (portalURL.contains(groupRegEx)) {
+			String[] splits = portalURL.split(groupRegEx);
+			String friendlyURL = splits[1];
+			if (friendlyURL.contains("/")) {
+				friendlyURL = friendlyURL.split("/")[0];
+			} else {
+				friendlyURL = friendlyURL.split("\\?")[0].split("\\#")[0];
+			}
+			return "/"+friendlyURL;
+		}
+		return null;
+	}
+
 	/**
 	 * Send an email to the administrator as well as the 
 	 * @param bean
@@ -529,6 +563,9 @@ public class SocialCommunications {
 						replace("ORIGINAL_USER", rInfo.getFullNameOriginalAdmin());
 				String subject = "Revert merge request on GRSF Record";
 
+				messageToEditor = messageToEditor.replace("<br>", "\n");
+				messageToReviewer = messageToReviewer.replace("<br>", "\n");
+
 				// send email to the editor
 				logger.info("The message that is going to be send to the editor is\n" + messageToEditor);
 				HttpPost postRequest = new HttpPost(basePath + SOCIAL_SEND_EMAIL + "?gcube-token=" + applicationToken);
